@@ -9,6 +9,7 @@ use warnings;
 package Net::SIP::SocketPool;
 use fields qw(loop ipproto tls dst fds tids cb timeout_timer);
 
+use Errno qw(ETIMEDOUT);
 use Net::SIP::Util ':all';
 use Net::SIP::Packet;
 use Net::SIP::Debug;
@@ -243,12 +244,13 @@ sub sendto {
     }
 
     if ($self->{ipproto} eq 'tcp') {
-	if ($fo->{peer}) {
+	if ($fo && $fo->{peer}) {
 	    $DEBUG && DEBUG(40,"send tcp data to %s via %s",
 		ip_parts2string($dst),
 		ip_parts2string($fo->{peer}));
 	    # send over this connected socket
 	    $fo->{wbuf} .= $data;
+	    $fo->{error_cb} = $callback;
 	    _tcp_send($self,$fo,$callback) if ! $fo->{inside_connect};
 	    return;
 	}
@@ -269,6 +271,7 @@ sub sendto {
 	    wbuf => $data,
 	    didit => $self->{loop}->looptime,
 	    inside_connect => 1,
+	    error_cb => $callback,
 	});
 	_tcp_connect($self,$fo,ip_parts2sockaddr($dst),$callback);
 	return;
@@ -317,6 +320,7 @@ sub _timeout_sockets {
 	    $self->_del_socket($_);
 	} elsif ($_->{inside_connect} && $tdiff > $CONNECT_TIMEOUT) {
 	    $self->_del_socket($_,"connect timed out");
+	    invoke_callback($_->{error_cb}, ETIMEDOUT) if $_->{error_cb};
 	} else {
 	    $need_timer = 1;
 	}
